@@ -403,9 +403,9 @@ class PyChess:
         self.handleArgs(args)
     
     def mainWindowSize (self, window):
-        def savePosition (window, event):
-            conf.set("window_width",  window.get_size()[0])
-            conf.set("window_height", window.get_size()[1])
+        def savePosition (window, *event):
+            conf.set("window_width",  window.get_allocation().width)
+            conf.set("window_height", window.get_allocation().height)
             conf.set("window_x", window.get_position()[0])
             conf.set("window_y", window.get_position()[1])
         window.connect("delete-event", savePosition)
@@ -415,7 +415,7 @@ class PyChess:
             height = conf.get("window_height", 479)
             assert width > 0
             assert height > 0
-            window.resize(width, height)
+            window.set_size_request(width, height)
             x = conf.get("window_x", gtk.gdk.screen_width()/2-width/2)
             # As default, put center on upper golden ratio line
             y = conf.get("window_y", int(gtk.gdk.screen_height()/2.618)-height/2)
@@ -425,9 +425,10 @@ class PyChess:
         # In rare cases, gtk throws some gtk_size_allocation error, which is
         # probably a race condition. To avoid the window forgets its size in
         # these cases, we add this extra hook
-        def callback (*args):
+        def callback (window, *args):
             window.disconnect(handle_id)
             loadPosition(window)
+            gobject.idle_add(window.set_size_request, -1, -1)
         handle_id = window.connect("size-allocate", callback)
     
     def initGlade(self):
